@@ -4,7 +4,7 @@ package POE::Component::ElasticSearch::Indexer;
 use strict;
 use warnings;
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use Const::Fast;
 use Digest::SHA1 qw(sha1_hex);
@@ -490,7 +490,8 @@ sub es_cleanup {
         return unless $p->basename =~ /\.batch$/;
 
         # Figure out the average size
-        $total += my $size = $p->stat->size;
+        my $size = $p->stat->size;
+        $total += $size;
         push @files, {
             path  => $p,
             size  => $size,
@@ -586,7 +587,7 @@ POE::Component::ElasticSearch::Indexer - POE session to index data to ElasticSea
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
